#!/usr/bin/env python3
"""GCD game script."""

from brain_games.engine import run_game
from brain_games.games import gcd


def main():
    """GCD game script."""
    run_game(gcd)


if __name__ == '__main__':
    main()



"""Progression game engine."""

import random

GAME_DESCRIPTION = 'What number is missing in the progression?'

START_MIN = 1
START_MAX = 20
STEP_MIN = 1
STEP_MAX = 10
PROGERSSION_LENGTH = 10


def get_challenge():
    """Progression game Q&A generation.

    It forms an arithmetic progression,
    replacing one of the numbers with two points.

    Returns:
        question{str} : arithmetic progression;
        answer{str} : hidden number
    """
    start = random.randint(START_MIN, START_MAX)
    step = random.randint(STEP_MIN, STEP_MAX)
    progression = [(start + (ind * step))
                   for ind in range(PROGERSSION_LENGTH)]
    hidden_element_index = random.randint(0, PROGERSSION_LENGTH - 1)
    answer = str(progression[hidden_element_index])
    progression[hidden_element_index] = '..'
    question = ' '.join(str(ind) for ind in progression)
    return (question, answer)



"""Command line interface (only for brain_games.py)."""

import prompt


def welcome_user():  # function name from step 3 of project
    """Welcome dialog."""
    name = prompt.string('May I have your name? ')
    print('Hello, {}!'.format(name))



"""Brain Games Engine."""

import prompt

NUMBER_OF_STEPS = 3


def run_game(game):
    """Brain Games Engine.

    Executing game process

    Args:
        game (function): create game question and answer
    """
    print('Welcome to the Brain Games!\n{}\n'.format(game.GAME_DESCRIPTION))
    user_name = prompt.string('May I have your name? ')
    print('Hello, {}!\n'.format(user_name))
    for step in range(NUMBER_OF_STEPS):
        (game_question, game_answer) = game.get_challenge()
        user_answer = prompt.string(
            'Question: {}\nYour answer: '.format(game_question))
        if user_answer != game_answer:
            print("'{}' is wrong answer ;(. Correct answer was '{}'.".format(
                user_answer, game_answer))
            print("Let's try again, {}!".format(user_name))
            return
        print('Correct!')
    print('Congratulations, {}'.format(user_name))



"""Even game engine."""

import random

GAME_DESCRIPTION = "Answer 'yes' if number even otherwise answer 'no'."

MIN_NUM = 1
MAX_NUM = 20


def get_challenge():
    """Even game Q&A generation.

    generate random Number and check if a Number is Even

    Returns:
        question{str} : Number;
        answer{str} : Even status
    """
    num = random.randint(MIN_NUM, MAX_NUM)
    answer = 'no' if num % 2 else 'yes'
    question = '{}'.format(num)
    return (question, answer)



"""Prime game engine."""

import random

GAME_DESCRIPTION = 'Answer "yes" if number prime otherwise answer "no".'

MIN_NUM = 1
MAX_NUM = 100


def get_challenge():
    """Prime game Q&A generation.

    generate random Number and check if a Number is Prime

    Returns:
        question{str} : Number;
        answer{str} : Prime status
    """
    num = random.randint(MIN_NUM, MAX_NUM)
    answer = 'yes' if is_prime(num) else 'no'
    question = '{}'.format(num)
    return (question, answer)


def is_prime(num):
    """Prime number check.

    Args:
        num (int): number to check

    Returns:
        bool: True or False
    """
    if num < 2:
        return False
    index = 2
    while index <= num // 2:
        if num % index == 0:
            return False
        index += 1
    return True



#!/usr/bin/env python3
"""Progression game script."""


from brain_games.engine import run_game
from brain_games.games import progression


def main():
    """Progression game script."""
    run_game(progression)


if __name__ == '__main__':
    main()



"""GCD game engine."""

import random

GAME_DESCRIPTION = 'Find the greatest common divisor of given numbers.'

MIN_NUM = 1
MAX_NUM = 100


def get_challenge():
    """GCD game Q&A generation.

    generate two random Numbers
    and calculate greatest common divider for them

    Returns:
        question{str} : Numbers;
        answer{str} : greatest common divider
    """
    num1 = random.randint(MIN_NUM, MAX_NUM)
    num2 = random.randint(MIN_NUM, MAX_NUM)
    answer = str(gcd(num1, num2))
    question = '{} {}'.format(num1, num2)
    return (question, answer)


def gcd(num1, num2):
    """Find greater common divider.

    Find greater common divider
    for two integer numbers

    Args:
        num1 (int): number one
        num2 (int): number two

    Returns:
        int: Greater Common Divider
    """
    while num1 != num2:
        if num1 > num2:
            num1 -= num2
        else:
            num2 -= num1
    return (num1)



#!/usr/bin/env python3
"""Calc game script."""

from brain_games.engine import run_game
from brain_games.games import calc


def main():
    """Calc game script."""
    run_game(calc)


if __name__ == '__main__':
    main()



"""Calc game engine."""

import random
from operator import add, mul, sub

GAME_DESCRIPTION = 'What is the result of the expression?'

OPERATIONS = [(add, '+'), (sub, '-'), (mul, '*')]

MIN_NUM = 1
MAX_NUM = 20


def get_challenge():
    """Calc game Q&A generation.

    generate two random numbers
    and calculate result of random operation from list

    Returns:
        question{str} : operation description;
        answer{str} : result of operation
    """
    num1 = random.randint(MIN_NUM, MAX_NUM)
    num2 = random.randint(MIN_NUM, MAX_NUM)
    operation, sign = random.choice(OPERATIONS)
    answer = str(operation(num1, num2))
    question = '{} {} {}'.format(num1, sign, num2)
    return (question, answer)
